Coverage for beyonic: 100%

# Coverage for beyonic : 100%

## 9 statements 9 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | # Beyonic API Python bindings #default values if any DEFAULT_ENDPOINT_BASE = 'https://app.beyonic.com/api/' #config api_key = None api_endpoint_base = None api_version = None verify_ssl_certs = True #set to False if you want to bypass SSL checks(mostly useful while testing it on local env). from beyonic.apis.payment import Payment from beyonic.apis.webhook import Webhook from beyonic.apis.collection import Collection from beyonic.apis.collectionrequest import CollectionRequest